@@ -42,10 +42,7 @@ class AudioDialog : public AudioDialogData
     void setChannels(int);
     void setFrequency(int);
     void setBitsPerSample(int p)  { setPrecision(p); }  // old name
-
- signals:
-
-    void changed(const AudioConfig&);
+    void setDriver( const QString& );
 };
 
 #endif  /* AUDIODIALOG_H */
