@@ -19,12 +19,12 @@
 // --------------------------------------------------------------------------
 
 #ifdef XSID_WB_DEBUG
-#include <iomanip.h>
-#include <iostream.h>
+#include <iomanip>
 #endif
-#include <fstream.h>
-#include <stdlib.h>
-#include <unistd.h>
+#include <fstream>
+#include <iostream>
+#include <cstdlib>
+using namespace std;
 
 #include "ConfigFileOld.h"
 #include "ConfigFile.h"
