@@ -31,6 +31,12 @@ FilterDialog::FilterDialog(QWidget* parent, const char* name,
 {
     setIcon(*mainIcon);
 
+    // TODO: move into .ui
+    setTabOrder( isEnabled, para1Sld );
+    setTabOrder( para1Sld, para2Sld );
+    setTabOrder( para2Sld, para3Sld );
+    setTabOrder( para3Sld, defaultBtn );
+
     enableChangedSignal(true);
     setButtons();
     paintFilterFunc();
