@@ -18,6 +18,9 @@
 #define MAINDIALOG_H
 
 class Playlist;
+#ifdef XSID_HAVE_TSID
+class TSID;
+#endif
 
 #include <qapplication.h>
 #include <qbitmap.h>
@@ -31,6 +34,10 @@ class Playlist;
 #include <qstring.h>
 #include <qtooltip.h>
 
+#ifdef XSID_HAVE_LIRC
+#include <lirc/lirc_client.h>
+#endif
+
 class AudioDialog;
 class EmuDialog;
 class FilterDialog;
@@ -40,7 +47,6 @@ class MixerDialog;
 class PlaylistDialog;
 class PlaylistEditDialog;
 class StilDialog;
-class WaveViewDialog;
 
 class ConfigFile;
 class AudioConfig;
@@ -49,7 +55,7 @@ class HVSC_Config;
 class MixerConfig;
 class Player;
 class PlaylistItem;
-class SidTuneMod;
+class SidTuneWrapper;
 
 #include "MainDialogData.h"
 #include "stilview/stil.h"
@@ -81,7 +87,7 @@ public:
     // For config saver and internal use as wrapper.
     bool isSongLenDbEnabled();
     void setSongLenDbEnabled(bool);
-    int querySongLengthDB(SidTuneMod*, int song);
+    int querySongLengthDB(SidTuneWrapper*, int song);
 
     void setup(ConfigFile*, const QString&, Player*);
     bool writeConfig();
@@ -92,7 +98,6 @@ public:
 public slots:
     void playerButtonsForceStop();
     
-    void receiveAudioConfig(const AudioConfig&);
     void receiveEmuConfig(const emuConfig&);
     void receiveHVSC_Config(const HVSC_Config&);
     void receiveMixerConfig(const MixerConfig&);
@@ -100,7 +105,7 @@ public slots:
     void playFile(const QString&);
     void playHistoryFile(const QString&);
     void playPlaylistFile(const PlaylistItem&);
-    void playFileMain(const QString&, int song, bool putInHistory, bool enablePlaylist);
+    void playFileMain( const QString&, int song, const PlaylistItem&, bool putInHistory, bool enablePlaylist );
     
     void openFile();
     void saveAs();
@@ -117,7 +122,6 @@ public slots:
     void openHVSC_Dialog();
     void openHistoryDialog();
     void openMixerDialog();
-    void openWaveViewDialog();
     
     void openPlaylistDialog();
     void openPlaylistEditDialog();
@@ -150,7 +154,6 @@ public slots:
     PlaylistDialog* myPlaylistDlg;
     PlaylistEditDialog* myPlaylistEditDlg;
     StilDialog* myStilDlg;
-    WaveViewDialog* myWaveViewDlg;
 
     QPixmap* prevPic;
     QPixmap* stopPic;
@@ -177,21 +180,21 @@ public slots:
 
     void programExitHook();
     
-    void loadSidTune(const QString&, int song, bool putInHistory);
-    void startLoaded();
-    
     void addTuneToPlaylistMain(PlaylistItem*);
     void addDirMain(bool recurse);
-    void addDirTraverse(QString, bool recurse, SidTuneMod*);
+    void addDirTraverse(QString, bool recurse, SidTuneWrapper*);
 
     const QString& fetchLastDir(const char* group);
-    void storeLastDir(const char* group, QString&);
+    void storeLastDir(const char* group, const QString&);
     
     void resetTimeDisplay();
 
     void closeEvent(QCloseEvent*);
-    void hideEvent(QHideEvent*);
     void resizeEvent(QResizeEvent*);
+
+#ifdef XSID_HAVE_TSID
+    void addTSID();
+#endif
     
  protected slots:
 
@@ -212,11 +215,13 @@ public slots:
     void setLoopPlayEnabled(bool);
     void setRandomPlayEnabled(bool);
     
+    void lircEvent(int);
+
  private:
     
     QMenuBar *menuBar;
     QPopupMenu *extraMenu;
-    int waveViewID, stilID, songLenDbID;
+    int stilID, songLenDbID;
 
     ConfigFile* config;
     QString configPath;
@@ -233,6 +238,16 @@ public slots:
     // The currently active file name, and the part of it
     // which is relative to the HVSC root (if any).
     QString sidFileNameFull, sidFileNameHVSC;
+    
+#ifdef XSID_HAVE_TSID
+    TSID* myTSID;
+#endif
+
+#ifdef XSID_HAVE_LIRC
+  int lircfh;
+  struct lirc_config *lircConfig;
+#endif
+
 };
 
 inline bool MainDialog::isStilInfoEnabled()
