@@ -24,15 +24,18 @@ class AudioBase
 protected:  // ---------------------------------------------------- protected
 	
 	AudioConfig config;
-	char* errorString;
+    const char* errorString;
 
 public:  // ---------------------------------------------------------- public
 	
 	AudioBase() { errorString = "No driver."; }
 	virtual ~AudioBase() { ; }
 
+    virtual const char* getName() const = 0;
+   
 	virtual bool open(const AudioConfig& srcConfig) = 0;
 	virtual void close() = 0;
+    virtual void unload() = 0;
 	virtual bool reset() = 0;
 	virtual void play(void* buffer, unsigned long int bufferSize) = 0;
 
@@ -40,7 +43,7 @@ public:  // ---------------------------------------------------------- public
 	{
 		return config;
 	}
-	
+
 	const char* getErrorString() const
 	{
 		return errorString;
