@@ -37,6 +37,10 @@ class PicButton : public QButton
 
     void drawButton (QPainter*);
     QPixmap* pixmap;
+    
+    // Prevent copying.
+    PicButton(const PicButton&);
+    PicButton& operator=(PicButton&);  
 };
 
 #endif  /* PICBUTTON_H */
