@@ -138,6 +138,8 @@ int main(int argc, char** argv)
     }
     else
     {
+        // Load a global config file.
+        config->load( "/etc/xsidplay.ini" );
         config->load();
     }
 
